<div class="card spotify">
    <form ng-submit="spotifyLogin()">
        <fieldset>
            <div class="row">
                <legend><img src="/img/s.png"/> Login to Spotify</legend>
            </div>
            <div class="row">
                <div class="span3">
                    <label>Username</label>
                    <input type="text" ng-model="loginData.username" required  placeholder="Username">
                    <label>Password</label>
                    <input type="password" ng-model="loginData.password" required  placeholder="Password">
                    <button type="submit" class="btn btn-success">Submit</button>
                </div>
                <div class="span5 pull-right">
                    <div class="alert alert-success">
                        <button type="button" class="close" data-dismiss="alert">&times;</button>
                        <strong>Heads up!</strong> You need to have a Spotify Premium account. If you're logging in with Facebook make sure you use your device password (you can look that up on your Spotify account page).
                    </div>
                </div>
            </div>
        </fieldset>
    </form>
</div>