body {
    margin: 0px;
    padding: 0px;
}

.container {
    margin: 0px;
    padding: 0px;
    width: auto;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 60px;
}

.additional_bottom {
    margin-top: 10px;
    margin-bottom: 10px;
}

.container div.card {
    position: absolute;
    left: 0;
    right: 0;
    bottom: 24px;
    top: 0;
    overflow-y: auto;
}

.row {
    margin-left: auto;
}

.bottom_bar {
    z-index: 5;
    position: absolute;
    bottom: 0px;
    height: 60px;
    left: 0px;
    right: 0px;
    background: #7F8C8D;
    border-top: 4px solid #ffffff;
    padding: 10px;
}

.card {
    padding: 10px;
}

.portify {
    background: #E67E22;
    color: #ffffff;
}

.process_top {
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    height: 30px;
    background: rgba(133,133,133,0.6);
    opacity: 0.6;
    z-index: 9;
    color: #ffffff;
    font-weight: bold;
    font-size: 13pt;
    line-height: 25px;
    padding-left: 5px;
}

.notfound {
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 23px;
    background: rgba(133,133,133,1);
    color: #ffffff;
    opacity: 1;
    z-index: 16;
    padding: 14px;
    overflow-y: auto;
}

.notfound a {
    color: #ffffff;
}

.done {
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    background: rgba(133,133,133,0.8);
    opacity: 1;
    z-index: 15;
    color: #ffffff;
    font-weight: bold;
    font-size: 13pt;
    text-align: center;
}

.done h1 {
    margin-top: 25%;
}
.done a {
    color: #FFFFFF;
}


.ok,.nok {
    position: absolute; z-index: 5; right: 10px; bottom: 0px;
    display: block;
}

.ok,.nok {
    font-size: 300%;
    opacity: 0.6;
}

.nok {
    z-index: 6;
}

/*
.process div {
    -webkit-filter: grayscale(1);
    -webkit-transition:-webkit-filter 0.8s ease-in-out;
}*/

.album {
    width: 10%;
    float: left;
    position: relative;
}

.process div.color {
    -webkit-filter: grayscale(0);
}

.view-anim-leave {
    -webkit-transition: .5s linear opacity;
    opacity: 1;
}

.view-anim-leave.view-anim-leave-active {
    opacity: 0;
}

.view-anim-enter, done-anim-enter {
    -webkit-transition: .5s linear opacity;

    opacity: 0;
}

.view-anim-enter.view-anim-enter-active, .done-anim-enter.done-anim-enter-active {
    opacity: 1;
}

.row {
    right: 0px;
    left: 0px;
}

.col {
    position: relative;
    width: 10%;
    padding-bottom: 10%;
    float: left;
    height: 0;
    box-sizing: border-box;
}

.current_playlist {
    position: absolute;
    left: 5%;
    right: 5%;
    top: 50%;
    height: 200px;
    background: #7F8C8D;
    z-index: 100;
    margin-top: -100px;
}

.current_playlist .progress .bar {
    background: #E67E22;
}
.current_playlist .progress {
    border-radius: 0px;
    margin-bottom: 5px;
}

.process_details {
    padding: 0px 10px 0px 10px;
}

.process_details h1 {
    margin-bottom: 20px;
}

.process_details {
    font-size: 205%;
    text-align: center;
}


.simpleprocess-anim-enter {
    -webkit-animation-duration: 1s;
    -webkit-animation-delay: .5s;
    -webkit-animation-timing-function: ease;
    -webkit-animation-fill-mode: both;
    opacity: 0;
}

.simpleprocess-anim-enter.simpleprocess-anim-enter-active {
    -webkit-animation-name: bounceInDown;
    opacity: 1;
}

.simpleprocess-anim-leave {
    -webkit-animation-duration: 1s;
    -webkit-animation-delay: .5s;
    -webkit-animation-timing-function: ease;
    -webkit-animation-fill-mode: both;
    opacity: 1;
}

.simpleprocess-anim-leave.simpleprocess-anim-leave-active {
    -webkit-animation-name: bounceOutDown;
}


.album-anim-enter {
    -webkit-animation-duration: .8s;
    -webkit-animation-delay: .1s;
    -webkit-animation-timing-function: ease;
    -webkit-animation-fill-mode: both;
    opacity: 0;
}

.album-anim-enter.album-anim-enter-active {
    -webkit-animation-name: fadeIn;
    opacity: 1;
}

.album-anim-leave {
    -webkit-animation-duration: .5s;
    -webkit-animation-delay: 0s;
    -webkit-animation-timing-function: ease;
    opacity: 1;
}

.album-anim-leave.album-anim-leave-active {
    -webkit-animation-name: fadeOut;
}

.placeholder {
    background: url('../img/no_album.png');
}

.container div.process {
    padding: 0px;
    margin: 0px;
    overflow-y: hidden;
    -webkit-user-select: none;
    background-image: url('/img/big_cover.png');
    -webkit-transition:-webkit-filter 0.8s ease-in-out, background 1s linear;

    background-size: cover !important;
    background-repeat: no-repeat !important;
}

.blur {
    -webkit-filter: blur(5px);
}

.album img {
    width: 100%;
}

.portify a {
    color: #ffffff;
}

.google {
    background: #2980B9;
    color: #ffffff;
}

.google legend {
    color: #ffffff;
}

.spotify {
    background: #9cca3b;
    color: #ffffff;
}

.spotify table {
    background: #ECF0F1;
}

.spotify thead {
    background: #BDC3C7;
}

.spotify tbody {
    color: #7F8C8D;
}

.spotify legend {
    color: #ffffff;
}

.test {
    -webkit-animation-duration: 1s;
    -webkit-animation-delay: .2s;
    -webkit-animation-timing-function: ease;
    -webkit-animation-fill-mode: both;
}

fieldset .btn {
    margin-bottom: 10px;
}

.intro_text {
    float: left;
    width: 50%;
    font-size: 16pt;
}

.intro_logo {
    float: right;
    width: 50%;
    text-align: right;
}

.bottom_bar .btn.btn-primary {
    background-color: #BDC3C7;
}

.bottom_bar .btn.btn-primary:hover, .btn.btn-primary:focus, .btn-group:focus .btn.btn-primary.dropdown-toggle {
    background-color: #95A5A6;
}

.bottom_bar .btn.btn-primary:active, .btn-group.open .btn.btn-primary.dropdown-toggle, .btn.btn-primary.active {
    background-color: #E67E22;
}

.pagination {
    margin: 10px 0;
}

::-webkit-scrollbar {
    height: 12px;
    width: 12px;
}
::-webkit-scrollbar-thumb {
    background: rgba(0, 0, 0, 0.35);
    -webkit-border-radius: 1ex;
    -webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.55);
}
::-webkit-scrollbar-corner {
    background: #000;
}