<div class="card portify">
    <div class="row">
        <h2>Welcome.</h2>
    </div>
    <div class="intro_text">
        <p>Pyportify can help you move all your beloved playlists from Spotify to Google Music: All Access<br/><br/></p>
        <small>However by using Pyportify you may violate both Spotify's and Google's Terms of Service. You agree that
           you are using Pyportify on your own risk. The author does not accept liability (as far as permitted by law) for any loss arising from any use of this tool.
           If you choose not to agree to these terms, then you may not use this tool.</small>
        <br/><br/>
        <a href="#/google/login" class="btn btn-large btn-danger">Get started.</a><br/><br/>
    </div>
    <div class="intro_logo">
        <img src="img/portify.svg" width="85%"/>
    </div>
</div>
