<div class="card portify">
    <div class="row">
        <div>
            <h1><img src="/img/portify.svg" width="60px"> {{app_name}}</h1>
            <p>
                Author: Josh Braegger <rckclmbr@gmail.com><br />
                Based on the original nodejs Portify by Sebastian Mauer<br />
                Licensed under the terms of the <a href="http://www.apache.org/licenses/LICENSE-2.0.html" target="_blank">Apache 2.0 License</a><br/><br/>
                Available on GitHub: <a href="http://github.com/rckclmbr/pyportify" target="_blank">http://github.com/rckclmbr/pyportify</a>
            </p>
        </div>

        <h3>Powered by</h3>
        <div style="font-size: 54pt; line-height: 86px;">
            <img src="/img/appjs.png">+<img src="/img/nodejs.png">+<img src="/img/angularjs.png">
        </div>
        <br><br/>
        Contributors:<br/>
        <a href="https://plus.google.com/114565490242017635471/posts">Eric Barmeyer</a><br/><br/>
        All trademarks are the property of their respective owners.

        <div style="position: absolute; right: 10px; top: 10px;">
            <div class="g-plus" data-width="307" data-height="69" data-href="//plus.google.com/118347291618073124443" data-rel="author"></div>
        </div>
    </div>
</div>
<!-- Place this tag after the last badge tag. -->
<script type="text/javascript">
    (function() {
        var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
        po.src = 'https://apis.google.com/js/plusone.js';
        var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
    })();
</script>
